Reduce the vertex count of an sf object via the optional rmapshaper
package (falling back to sf::st_simplify()), for fast web/plotting.
Examples
if (FALSE) { # \dontrun{
world_geometry(geometry = "sf") |> simplify_geometry(keep = 0.1)
} # }
Reduce the vertex count of an sf object via the optional rmapshaper
package (falling back to sf::st_simplify()), for fast web/plotting.
if (FALSE) { # \dontrun{
world_geometry(geometry = "sf") |> simplify_geometry(keep = 0.1)
} # }